@@ -14,7 +14,9 @@ use Plack::Util;
 use GrowthForecast;
 use GrowthForecast::Web;
 use GrowthForecast::Worker;
+use IO::Socket::UNIX;
 use Proclet;
+use Starlet '0.21';
 use File::ShareDir qw/dist_dir/;
 use Cwd;
 use File::Path qw/mkpath/;
@@ -29,6 +31,7 @@ Getopt::Long::Configure ("no_ignore_case");
 GetOptions(
     'port=s' => \$port,
     'host=s' => \$host,
+    'socket=s' => \my $socket,
     'front-proxy=s' => \@front_proxy,
     'allow-from=s' => \@allow_from,
     'disable-1min-metrics' => \my $disable_short,
@@ -71,6 +74,21 @@ else {
     unlink("$data_dir/$$.tmp");
 }
 
+my $sock;
+if ( $socket ) {
+    if (-S $socket) {
+        warn "removing existing socket file:$socket";
+        unlink $socket
+            or die "failed to remove existing socket file:$socket:$!";
+    }
+    unlink $socket;
+    $sock = IO::Socket::UNIX->new(
+        Listen => Socket::SOMAXCONN(),
+        Local  => $socket,
+    ) or die "failed to listen to file $socket:$!";
+    $ENV{SERVER_STARTER_PORT} = $socket."=".$sock->fileno;
+}
+
 my $proclet = Proclet->new;
 $proclet->service(
     code => sub {
@@ -114,7 +132,10 @@ $proclet->service(
         my $app = builder {
             enable 'Lint';
             enable 'StackTrace';
-            if ( @front_proxy ) {
+            if ( $sock ) {
+                enable 'ReverseProxy';
+            }
+            elsif ( @front_proxy ) {
                 enable match_if addr(\@front_proxy), 'ReverseProxy';
             }
             if ( @allow_from ) {
@@ -134,7 +155,7 @@ $proclet->service(
                                              });
                 }
             };
-            my $static_regexp = qr!^/(?:(?:css|js|images)/|favicon\.ico$)!;
+            my $static_regexp = qr!^/(?:(?:css|fonts|js|images)/|favicon\.ico$)!;
             enable 'Static',
                 path => $mount ? sub { s!^/$mount!!; $_ =~ $static_regexp } : $static_regexp,
                 root => $root_dir . '/public';
@@ -236,6 +257,10 @@ TCP port listen on. Default is 5125
 
 IP address to listen on
 
+=item --socket
+
+File path to UNIX domain socket to bind. If enabled unix domain socket, GrowthForecast does not bind any TCP port
+
 =item --front-proxy
 
 IP addresses or CIDR of reverse proxy
