@@ -48,7 +48,7 @@ CREATE TABLE IF NOT EXISTS graphs (
     sllimit      $number_type NOT NULL DEFAULT 0,
     type         VARCHAR(255) NOT NULL DEFAULT 'AREA',
     stype        VARCHAR(255) NOT NULL DEFAULT 'AREA',
-    meta         TEXT NOT NULL,
+    meta         TEXT,
     created_at   INT UNSIGNED NOT NULL,
     updated_at   INT UNSIGNED NOT NULL,
     PRIMARY KEY (id),
@@ -86,7 +86,7 @@ CREATE TABLE IF NOT EXISTS complex_graphs (
     number       $complex_number_type UNSIGNED NOT NULL DEFAULT 0,
     description  VARCHAR(255) NOT NULL DEFAULT '',
     sort         INT UNSIGNED NOT NULL DEFAULT 0,
-    meta         TEXT NOT NULL,
+    meta         TEXT,
     created_at   INT UNSIGNED NOT NULL,
     updated_at   INT UNSIGNED NOT NULL,
     PRIMARY KEY (id),
